package com.ruoyi.care.mapper;

import java.util.List;
import com.ruoyi.care.domain.CarePersons;

/**
 * 特困人员Mapper接口
 * 
 * @author qy
 * @date 2024-11-25
 */
public interface CarePersonsMapper 
{
    /**
     * 查询特困人员
     * 
     * @param personId 特困人员主键
     * @return 特困人员
     */
    public CarePersons selectCarePersonsByPersonId(Long personId);

    /**
     * 查询特困人员列表
     * 
     * @param carePersons 特困人员
     * @return 特困人员集合
     */
    public List<CarePersons> selectCarePersonsList(CarePersons carePersons);

    /**
     * 新增特困人员
     * 
     * @param carePersons 特困人员
     * @return 结果
     */
    public int insertCarePersons(CarePersons carePersons);

    /**
     * 修改特困人员
     * 
     * @param carePersons 特困人员
     * @return 结果
     */
    public int updateCarePersons(CarePersons carePersons);

    /**
     * 删除特困人员
     * 
     * @param personId 特困人员主键
     * @return 结果
     */
    public int deleteCarePersonsByPersonId(Long personId);

    /**
     * 批量删除特困人员
     * 
     * @param personIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCarePersonsByPersonIds(Long[] personIds);
}
